CreditCardValidator class

Constructors

CreditCardValidator()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

isValid(String card, [dynamic stripBeforeValidation = true]) bool
strip(String card) String

Constants

maxLength → const int
minLength → const int
STRIP_REGEX → const String